@@ -1,2 +1,2 @@
-from .torchshow import show, show_video
+from .torchshow import show, show_video, save
 from .config import use_inline, set_image_std, set_image_mean, set_color_mode
\ No newline at end of file
